#!/bin/bash

# Runs all experiments listed at the bottom. Each experiment consists of a
# given number of repetitions using a particular base name for the weights and
# predictions files. Each single repetition checks if it was already run or is
# currently being run, creates a lockfile, trains the network, computes the
# predictions, and removes the lockfile. To distribute runs between multiple
# GPUs, just run this script multiple times with different THEANO_FLAGS.

train_if_free() {
	modelfile="$1"
	echo "$modelfile"
	if [ ! -f "$modelfile" ] && [ ! -f "$modelfile.lock" ]; then
		echo "$HOSTNAME: $THEANO_FLAGS" > "$modelfile.lock"
		OMP_NUM_THREADS=1 THEANO_FLAGS=allow_gc=1,dnn.conv.algo_fwd=guess_on_shape_change,dnn.conv.algo_bwd_data=guess_on_shape_change,dnn.conv.algo_bwd_filter=guess_on_shape_change,"$THEANO_FLAGS" ./train.py "$modelfile" --save-errors "${@:2}" --keep-state
		if [ "$2" == "--dataset" ]; then dataset="--dataset=$3"; else dataset=""; fi
		if [ "${modelfile:0:13}" == "birdclef/meta" ]; then
			./predict.py --var arch.output=linear "$modelfile" "${modelfile%.npz}.pred.pkl" $dataset
		else
		  OMP_NUM_THREADS=1 THEANO_FLAGS=allow_gc=1,dnn.conv.algo_fwd=guess_on_shape_change,dnn.conv.algo_bwd_data=guess_on_shape_change,dnn.conv.algo_bwd_filter=guess_on_shape_change,"$THEANO_FLAGS" ./predict.py --var arch.output=linear --var arch.output_bg= --var len_min=3 --var len_max=63 --split-pool "$modelfile" "${modelfile%.npz}.pred.pkl" $dataset
		fi
		rm "$modelfile.lock"
	fi
}

train() {
	repeats="$1"
	name="$2"
	for (( r=1; r<=$repeats; r++ )); do
		train_if_free "$name"$r.npz "${@:3}"
	done
}


mkdir -p birdclef
#for r in '' _r2 _r3; do
#    train_if_free birdclef/dummy_lme1_fdrop0_fM10k_powlearn_shift5$r.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5
#done
#train_if_free birdclef/stefanmodel1_lme1_fdrop05_fM10k_powlearn.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch=conv:64x7x7x2x1,pool:2x1,conv:128x5x5,pool:2x2,conv:256x3x3,pool:2x2,conv:512x3x3,pool:2x2,conv:1024x3x3,pool:2x2,Conv:512x1x-1,Conv:512x1x1
#train_if_free birdclef/dummy_lme1_fdrop0_fM10k_powlearn_shift5_fs1024.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr8dgr8.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=8 --var arch.dense_groups=8
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr8dgr4.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=8 --var arch.dense_groups=4
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr2dgr2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=2 --var arch.dense_groups=2
train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
#train_if_free birdclef/deepr_lme1_fdrop05_fM10k_powlearn_shift5_fs1024.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:32x3x3,conv:32x3x3,pool:2x2,conv:64x3x3,conv:64x3x3,pool:2x2,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr1_grpdrop02.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,groupdrop:4:0.2,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr1_wronggrpdrop02.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=1 --var arch.convdrop=groups --var arch.convdrop_rate=0.2
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_grpdrop01.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1,groupdrop:4:0.1' --var arch.conv_groups=4 --var arch.dense_groups=4
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_omixup01.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var mixup2=0.1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_mixup01.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var mixup=0.1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_pitch005.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var filterbank=mel_learn --var arch.mel_trainable=0 --var arch.mel_rndspread=0.05
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_etacy02-5.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var eta_cycle=0.2:5
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc4cgr1dgr1_bs12.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:128x3x3,conv:128x3x3,pool:3x3,conv:256x3x3,conv:256x3x3,conv:256x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var batchsize=12
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var ban=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var ban=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban1.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban1_cont.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_pseudoens1_r2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var pseudo_labels=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc3cgr1dgr1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc4cgr1dgr1_bs12.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban2.train.pred.pkl:softmax
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc3cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:96x3x3,conv:96x3x3,pool:3x3,conv:192x3x3,conv:192x3x3,conv:192x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc4cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:128x3x3,conv:128x3x3,pool:3x3,conv:256x3x3,conv:256x3x3,conv:256x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_convmeanfree.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var arch.firstconv_meanfree=params
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_pseudoban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var pseudo_labels=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4.train.pred.pkl:softmax
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_pseudoban2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var pseudo_labels=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_pseudoban1.train.pred.pkl:softmax
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_pseudoens1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4 --var pseudo_labels=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc3cgr1dgr1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc4cgr1dgr1_bs12.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban2.train.pred.pkl:softmax
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_pseudoens1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var pseudo_labels=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc3cgr1dgr1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc4cgr1dgr1_bs12.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban1.train.pred.pkl,birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr4dgr4_ban2.train.pred.pkl:softmax
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_eq10.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var spect_augment=1 --var max_db=10
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_pseudoban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var pseudo_labels=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.train.pred.pkl:softmax
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_pseudoban1_r1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var pseudo_labels=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.train.pred.pkl:softmax
train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var ban=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1_r1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var ban=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var ban=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_clsweightg05.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var class_weights=google:0.5
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1a4dgr4_grpdrop01.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='convg1:64x3x3,conv:64x3x3,pool:3x3,groupdrop:4:0.1,convg1:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,groupdrop:4:0.1,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.conv_groups=4 --var arch.dense_groups=4
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_reeu.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,avgpool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,avgpool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.nonlin=reeu
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_lme1pool.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,lme1pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,lme1pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_bgsigm.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.output_bg=sigmoid --var cost_bg=ce
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_bgsigmonly.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=none --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.output_bg=sigmoid --var cost_bg=ce
#train_if_free birdclef/dummy_attloss16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=attention_logsoftmax --var arch.output=linear --validate --var arch.prepool=logsoftmax --var arch.pool=attention_nopool:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
#train_if_free birdclef/dummy_att4_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:4 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
train_if_free birdclef/dummy_att64_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:64 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var ban=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz
train_if_free birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
#train_if_free birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_r1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
train_if_free birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
#pflaume#train_if_free birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var ban=birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_pcen_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pcen --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
train_if_free birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var ban=birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz
train_if_free birdclef/dummy_att64_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:64 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var ban=birdclef/dummy_att64_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM11k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=11000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_bs8_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=8 --var epochsize=2000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_lm45_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var len_max=45
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_bs24_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=24 --var epochsize=667 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_bs24_mixfgbg_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=24 --var epochsize=667 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var ban=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_bs24_mixfgbg.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_presoftmax.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var arch.prepool=logsoftmax --var cost=logsoftmax --var arch.output=linear
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_mb100_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var mel_bands=100
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn15_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn:-1.5 --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_lm15_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var len_max=15
train_if_free birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
train_if_free birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var ban=birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz
train_if_free birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var ban=birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz
train_if_free birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
train_if_free birdclef/resnet1_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
train_if_free birdclef/resnet1_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1
#train_if_free birdclef/resnet1_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var ban=birdclef/resnet1_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz
#train_if_free birdclef/resnet1_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var mix_fg_bg=1 --var ban=birdclef/resnet1_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_mixfgbg.npz
train_if_free birdclef/resnet1_att64_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:64 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'
train_if_free birdclef/resnet1_att64_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:64 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var ban=birdclef/resnet1_att64_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz
# after discovering two missing nonlinearities in the resnet model (recoverable with resnet.act_bug=1):
#train_if_free birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_nobug.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var batchsize=16 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1'

# metadata-only experiments
skip_spects="--var arch= --var len_min=0 --var len_max=0"
#train_if_free birdclef/meta-256-256_fdrop05.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0.5 --var epochsize=5000
#train_if_free birdclef/meta-256-256_fdrop0.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map
#train_if_free birdclef/meta-256-256_fdrop0_bn.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var arch_meta.batch_norm=1 --var epochsize=5000 --var patience_criterion=valid_map
#train_if_free birdclef/meta-256-256_fdrop0_dtenc3.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3
#train_if_free birdclef/meta-256-256_fdrop0_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var mix_fg_bg=1
#train_if_free birdclef/meta-256-256_fdrop0_mdrop01.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.dropout=0.1
#train_if_free birdclef/meta-256-512_fdrop0.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map
#train_if_free birdclef/meta-256_fdrop0.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map
#train_if_free birdclef/meta-256-256_fdrop0_dtenc3_r2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3
train_if_free birdclef/meta-256-512_fdrop0_dtenc3_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_dtenc3_mixfgbg_r2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-256_fdrop0_moreblur.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=14 --var input_meta.time_noise=30 --var input_meta.latitude_noise=3 --var input_meta.longitude_noise=3 --var input_meta.elevation_noise=100
#train_if_free birdclef/meta-256-256_fdrop0_lessblur.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=3 --var input_meta.time_noise=3 --var input_meta.latitude_noise=0.3 --var input_meta.longitude_noise=0.3 --var input_meta.elevation_noise=5
#train_if_free birdclef/meta-256-256_fdrop0_noblur.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0
#train_if_free birdclef/meta-256-256_fdrop0_noblur_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:256 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_noblur_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
#train_if_free birdclef/meta-512-512_fdrop0_noblur_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:512,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
#train_if_free birdclef/meta-512-1024_fdrop0.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:512,full:1024 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map
#train_if_free birdclef/meta-512-1024_fdrop02.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:512,full:1024 --var arch_meta.fulldrop=0.2 --var epochsize=5000 --var patience_criterion=valid_map
train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_noblur_nodate_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_noblur_notime_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_noblur_noloc_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_noblur_noelev_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc2_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=2 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc5_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=5 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg05.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=0.5
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg02.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=0.2
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_sigm.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=ce --var arch.output=sigmoid --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3
train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var ban=birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz
train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var ban=birdclef/meta-256-512_fdrop0_noblur_dtenc3.npz
#train_if_free birdclef/meta-256-512_fdrop0_noblur_onlydate_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_noblur_onlytime_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=time --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_noblur_onlyloc_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=latitude,longitude --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_noblur_onlyelev_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var mix_fg_bg=1
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_elu.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var arch_meta.nonlin=elu
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_l21e4.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var l2_decay=1e-4
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_l21e5.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var l2_decay=1e-5
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_l21e5_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var l2_decay=1e-5 --var ban=birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_l21e5.npz
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_l21e5.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var l2_decay=1e-5
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_l21e5_ban1.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var l2_decay=1e-5 --var ban=birdclef/meta-256-512_fdrop0_noblur_dtenc3_l21e5.npz
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg2.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=2
#train_if_free birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_sigm.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=ce --var arch.output=sigmoid --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_moreblur_dtenc3_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=14 --var input_meta.time_noise=30 --var input_meta.latitude_noise=3 --var input_meta.longitude_noise=3 --var input_meta.elevation_noise=100 --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_moreblur_dtenc3_nodate_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=14 --var input_meta.time_noise=30 --var input_meta.latitude_noise=3 --var input_meta.longitude_noise=3 --var input_meta.elevation_noise=100 --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_moreblur_dtenc3_notime_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=14 --var input_meta.time_noise=30 --var input_meta.latitude_noise=3 --var input_meta.longitude_noise=3 --var input_meta.elevation_noise=100 --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_moreblur_dtenc3_noloc_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=14 --var input_meta.time_noise=30 --var input_meta.latitude_noise=3 --var input_meta.longitude_noise=3 --var input_meta.elevation_noise=100 --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_moreblur_dtenc3_noelev_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_noise=14 --var input_meta.time_noise=30 --var input_meta.latitude_noise=3 --var input_meta.longitude_noise=3 --var input_meta.elevation_noise=100 --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_dtenc3_nodate_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=time,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_dtenc3_notime_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,latitude,longitude,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_dtenc3_noloc_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,elevation --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
train_if_free birdclef/meta-256-512_fdrop0_dtenc3_noelev_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 $skip_spects --var input_meta=date,time,latitude,longitude --var arch_meta=full:256,full:512 --var arch_meta.fulldrop=0 --var epochsize=5000 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1

# combination
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3
#train_if_free birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1
#train_if_free birdclef/dummy_att16_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3.npz --dataset birdclef --var eta_decay=0.1 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=attention:16 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_pretrained.npz --dataset birdclef --var eta=1e-5 --var eta_decay=0.5 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.weight=0.2 --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var init_from=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz:birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz
#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3_pretrained.npz --dataset birdclef --var eta=1e-5 --var eta_decay=0.5 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.weight=0.2 --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var init_from=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz:birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz
#astrud#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3_mixfgbg_pretrained.npz --dataset birdclef --var eta=1e-5 --var eta_decay=0.5 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.weight=0.2 --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var mix_fg_bg=1 --var init_from=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz:birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz
#astrud#train_if_free birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3_pretrained.npz --dataset birdclef --var eta=1e-5 --var eta_decay=0.5 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='conv:64x3x3,conv:64x3x3,pool:3x3,conv:128x3x3,conv:128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.weight=0.2 --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var init_from=birdclef/dummy_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_ban1.npz:birdclef/meta-256-512_fdrop0_noblur_dtenc3_mixfgbg.npz

# combination from pre-trained networks
#train_if_free birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_noblur_dtenc3_pretrained.npz --dataset birdclef --var initial_eta=1e-5 --var eta_decay=0.5 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.weight=0.22 --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_noise=0 --var input_meta.time_noise=0 --var input_meta.latitude_noise=0 --var input_meta.longitude_noise=0 --var input_meta.elevation_noise=0 --var input_meta.time_encoding.size=3 --var init_from=birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz:birdclef/meta-256-512_fdrop0_noblur_dtenc3.npz
train_if_free birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1_meta-256-512_fdrop0_dtenc3_pretrained.npz --dataset birdclef --var initial_eta=1e-5 --var eta_decay=0.5 --var eta_decay_every=trial_of_patience --var patience=10 --var trials_of_patience=3 --var epochs=1000 --var epochsize=1000 --var pred_clip=0 --var cost=softmax --var arch.output=softmax --validate --var arch.pool=logmeanexp:1 --var arch.fulldrop=0.5 --var mel_max=10000 --var magscale=pow_learn --var first_params_eta_scale=10 --var arch.shiftable=5 --var arch.fullsize=1024 --var arch='resblock_start:2x64x3x3,pool:3x3,resblock_end:2x128x3x3,conv:128x3x-Shift,pool:3xShift,Conv:Fullx9x-1,Conv:Fullx1x1' --var input_meta=date,time,latitude,longitude,elevation --var arch_meta='full:256,full:512' --var arch_meta.weight=0.33 --var arch_meta.fulldrop=0 --var patience_criterion=valid_map --var input_meta.date_encoding.size=3 --var input_meta.time_encoding.size=3 --var init_from=birdclef/resnet1_lme1_fdrop05_fM10k_powlearn_shift5_fs1024_mc2cgr1dgr1.npz:birdclef/meta-256-512_fdrop0_dtenc3_mixfgbg.npz
